@@ -14,10 +14,11 @@ EXEC_PATH = os.getcwd() + "/chromedriver"
 
 
 class ProxiedSeleniumPool:
-    def __init__(self, proxy_pool: ProxyPool, pool_size: int = 8, headless=True):
+    def __init__(self, proxy_pool: ProxyPool, pool_size: int = 8, headless=True, custom_flags=[]):
         self.__proxy_pool = proxy_pool
         self.__pool_size = pool_size
         self.__headless = headless
+        self.__custom_flags = custom_flags
 
         self.__sessions = Queue()
         for _ in range(pool_size):
@@ -42,6 +43,8 @@ class ProxiedSeleniumPool:
         chrome_options.add_argument('--disable-extensions')
         chrome_options.add_argument('--disable-default-apps')
         chrome_options.add_argument("ignore-certificate-errors")
+        for each in self.__custom_flags:
+            chrome_options.add_argument(each)
 
         return SeleniumSession(self.__proxy_pool.get_proxy,
                                service,
@@ -71,9 +74,12 @@ class SeleniumSession():
         self.__proxy_info = self.__fn_get_proxy()
         self.__options.add_argument("user-agent={}".format(self.__fn_get_useragent()))
         self.__options.add_argument("--proxy-server={}".format(self.__proxy_info.get_as_url()))
+        self.__options.add_experimental_option("excludeSwitches", ["enable-automation"])
+        self.__options.add_experimental_option('useAutomationExtension', False)
 
         self.__driver = webdriver.Remote(self.__service.service_url,
                                          options=self.__options)
+        self.__driver.execute_script("var s=window.document.createElement('script'); s.src='javascriptFirefox.js';window.document.head.appendChild(s);")
         return self.__proxy_info, self.__driver
 
     def __exit__(self, exc_type, exc_val, exc_tb):
